@@ -10,30 +10,30 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.27-52vl5.src.rpm ]
+if [ ! -r kernel-2.6.27-57vl5.src.rpm ]
 then
-    wget http://updates.vinelinux.org/Vine-5.0/updates/SRPMS/kernel-2.6.27-52vl5.src.rpm || die "Can't download source package."
+    wget http://updates.vinelinux.org/Vine-5.0/updates/SRPMS/kernel-2.6.27-57vl5.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.27-52vl5.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.27-52vl5.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.27-57vl5.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.27-57vl5.src.rpm || die "Can't install source package."
 
 cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.2-20100412.tar.gz ]
+if [ ! -r ccs-patch-1.7.2-20100604.tar.gz ]
 then
-    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20100412.tar.gz || die "Can't download patch."
+    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20100604.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/vine/SPECS/kernel-2.6-vl.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6-vl.spec	2010-01-09 11:18:54.000000000 +0900
-+++ kernel-2.6-vl.spec	2010-01-22 17:03:42.000000000 +0900
+--- kernel-2.6-vl.spec
++++ kernel-2.6-vl.spec
 @@ -27,7 +27,7 @@
- %define patchlevel 43
+ %define patchlevel 46
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
--%define release 52%{?_dist_release}
-+%define release 52%{?_dist_release}_tomoyo_1.7.2
+-%define release 57%{?_dist_release}
++%define release 57%{?_dist_release}_tomoyo_1.7.2p1
  
  %define make_target bzImage
  %define hdrarch %_target_cpu
@@ -56,18 +56,18 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -779,6 +782,10 @@
+@@ -787,6 +790,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.2-20100412.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.7.2-20100604.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.27-vine-linux-5.0.diff
 +
  cp %{SOURCE10} Documentation/
  
  # put Vine logo
-@@ -797,6 +804,9 @@
+@@ -805,6 +812,9 @@
  for i in *.config
  do 
  	mv $i .config 
